import os
import requests
import json

from awspy import AwsPy
from typing import Any


class Fargate(AwsPy):
    """
    Utilities for working with containers running on Fargate backed ECS
    NOT suitable for use with ECS tasks running on EC2 instances
    """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)
        self.ecs_container_metadata_uri_v4: str = os.environ.get(
            "ECS_CONTAINER_METADATA_URI_V4", ""
        )

    def get_container_metadata_v4(self) -> dict:
        """
        Extract the Fargate container metadata, injected into the running container by ECS.
        Note: This returns metadata for the current running container, NOT the task
        See https://docs.aws.amazon.com/AmazonECS/latest/userguide/task-metadata-endpoint-v4-fargate.html
        Requires Fargate platform version 1.4.0
        :return: ECS metadata dictionary:
            {
                "DockerId": "cd189a933e5849daa93386466019ab50-2495160603",
                "Name": "curl",
                "DockerName": "curl",
                "Image": "111122223333.dkr.ecr.us-west-2.amazonaws.com/curltest:latest",
                "ImageID": "sha256:25f3695bedfb454a50f12d127839a68ad3caf91e451c1da073db34c542c4d2cb",
                ...
            }
        :raises: requests.exceptions.RequestException, json.decoder.JSONDecodeError, RuntimeError
        """
        try:
            request = requests.get(self.ecs_container_metadata_uri_v4, timeout=3)
            if request.status_code == 200:
                json_metadata: str = request.json()
                return json_metadata
            else:
                raise RuntimeError(
                    f"Inappropriate response from metadata endpoint: {request.text}"
                )
        except Exception as e:
            if self._raise_errors:
                raise e
            else:
                self._logger.error(
                    f"Unable to read container metadata for endpoint: {self.ecs_container_metadata_uri_v4}: {e}"
                )
            return {}



import logging


class AwsPy:
    """
    Internal class to act as a common base for AWS services configuration
    """

    def __init__(
        self, raise_errors: bool = True, logger: logging.Logger = None
    ) -> None:
        """
        Configure instance
        :param raise_errors: Bool, halt execution and raise exceptions if True
        :param logger: Python logging instance to log to
        """

        self._raise_errors = raise_errors
        if logger:
            self._logger = logger
        else:
            self._logger = logging.getLogger(__name__)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="awspy",
    version="0.4.0",
    author="ScholarPack",
    author_email="dev@scholarpack.com",
    description="Utility tools for running Python services in AWS.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ScholarPack/awspy",
    packages=["awspy", "awspy.ecs"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
    install_requires=["requests >= 2.26.0", "types-requests >= 2.25.0"],
)